@@ -1,12 +1,11 @@
 
-options("rgdal_show_exportToProj4_warnings"="none") 
 library('mapmisc')
 
 
-pdf("colourScaleFile1.pdf",height=12,width=12)
+if(!interactive()) pdf("colourScaleFile1.pdf",height=12,width=12)
 par(mfrow=c(3,3))
 
-someData = SpatialPointsDataFrame(cbind(1:4, 1:4),data=data.frame(y=1:4))
+someData = vect(cbind(1:4, 1:4),atts=data.frame(y=1:4))
 
 cs=colourScale(someData$y,breaks=1:4,style='fixed',labels=c('a','b','c'))
 plot(someData, pch=16, col=cs$plot)
@@ -46,10 +45,11 @@ cs=colourScale(x=NA,breaks=1:4,style='unique',labels=c('a','b','c','d'),col=t(co
 legendBreaks('topleft', cs)
 legend('bottomright', fill=cs$col, legend=cs$legend)
 
-someData = SpatialPointsDataFrame(cbind(
+someData = vect(cbind(
 				sample(1:4, 12,replace=TRUE), 
 				sample(1:4, 12,replace=TRUE)),
-		data=data.frame(y=sample(0:5, 12,replace=TRUE)))
+		atts=data.frame(y=sample(0:5, 12,replace=TRUE)))
+
 cs=colourScale(x=someData$y,
 		breaks=1:4,style='unique',labels=c('a','b','c','d'),
 		col=t(col2rgb(heat.colors(4))), opacity=0.5,exclude='a')
@@ -67,10 +67,10 @@ forLegend = na.omit(cs$levels)
 legend('bottomright', fill=forLegend$col, legend=forLegend$label)
 
 
-someData = SpatialPointsDataFrame(cbind(
+someData = vect(cbind(
 				sample(1:4, 11,replace=TRUE), 
 				sample(1:4, 11,replace=TRUE)),
-		data=data.frame(y=0:10))
+		atts=data.frame(y=0:10))
 cs=colourScale(someData$y,breaks=4,style='equal',dec=2)
 plot(someData, pch=16, col=cs$plot)
 legendBreaks('topleft', cs)
@@ -96,11 +96,12 @@ cs=colourScale(x=someData$y,breaks=4,style='equal',exclude='nothing',dec=2)
 plot(someData, pch=16, col=cs$plot)
 legendBreaks('topleft', cs)
 
-myraster = raster(matrix(c(0:7,2), 3, 3))
+myraster = rast(matrix(c(0:7,2), 3, 3))
 cs=colourScale(x=myraster,breaks=4,style='equal',dec=2)
 plot(myraster, breaks=cs$breaks, col=cs$col,legend=FALSE)
 legendBreaks('topright', cs)
 
+
 cs=colourScale(x=myraster,breaks=4,style='quantile',dec=2)
 plot(myraster, breaks=cs$breaks, col=cs$col,legend=FALSE)
 legendBreaks('topright', cs)
@@ -130,13 +131,13 @@ legendBreaks('topright', cs)
 
 cs=colourScale(x=myraster,breaks=4,style='unique',exclude=0)
 legendBreaks('topright', cs)
-forLegend = na.omit(cs$levels)
+forLegend = na.omit(cs$levels)	
 legend('bottomright', fill=forLegend$col, legend=forLegend$label)
 
-someData = SpatialPointsDataFrame(cbind(
+someData = vect(cbind(
 				sample(1:4, 10,replace=TRUE), 
 				sample(1:4, 10,replace=TRUE)),
-		data=data.frame(y=factor(sample(0:4,10,replace=TRUE))))
+		atts=data.frame(y=factor(sample(0:4,10,replace=TRUE))))
 
 cs=colourScale(x=someData$y,breaks=4,
 		style='thisShouldBeIgnored',exclude='0')
@@ -145,5 +146,5 @@ legendBreaks('topleft', cs)
 forLegend = na.omit(cs$levels)
 legend('bottomright', fill=forLegend$col, legend=forLegend$label)
 
-dev.off()
+if(!interactive()) dev.off()
 
